@@ -1,6 +1,5 @@
 # %% imports
-from autogaita.resources.utils import bin_num_to_percentages
-from autogaita.group.group_utils import write_issues_to_textfile
+from autogaita.resources.utils import bin_num_to_percentages, write_issues_to_textfile
 import os
 import pandas as pd
 import numpy as np
@@ -95,7 +94,7 @@ def import_data(folderinfo, cfg):
                     tracking_software,
                     name,
                     which_leg,
-                    results_dir,
+                    folderinfo,
                     cfg,
                 )
             df_dict[which_df][g] = final_df_checks_and_save_to_xls(
@@ -109,7 +108,7 @@ def import_data(folderinfo, cfg):
     # test: is bin_num is consistent across our groups
     # => if so, add it as well as one_bin_in_% to cfg
     cfg["bin_num"] = test_bin_num_consistency(
-        df_dict["Normalised"], group_names, results_dir
+        df_dict["Normalised"], group_names, folderinfo
     )
     dfs = df_dict["Normalised"]
     raw_dfs = df_dict["Original"]
@@ -147,7 +146,7 @@ def final_df_checks_and_save_to_xls(
     return this_df
 
 
-def test_bin_num_consistency(dfs, group_names, results_dir):
+def test_bin_num_consistency(dfs, group_names, folderinfo):
     """Tests if bin number of step-cycle normalisation is consistent across groups"""
     # For this we use sc_breaks [i.e. the nan step-separators]) to see if bin_num is the
     # same value across all individual step-cycles across all groups.
@@ -166,17 +165,15 @@ def test_bin_num_consistency(dfs, group_names, results_dir):
             this_bin_num = sc_breaks[b] - sc_breaks[b - 1] - 1
             if this_bin_num != bin_num:
                 bin_num_error_helper_function(
-                    dfs, g, group_names, sc_breaks, results_dir, b
+                    folderinfo, dfs, g, group_names, sc_breaks, b
                 )
         # handle the last step-cycle of the df (it doesn't have a sc_break after it!)
         if (len(dfs[g]) - sc_breaks[-1] - 1) != this_bin_num:
-            bin_num_error_helper_function(
-                dfs, g, group_names, sc_breaks, results_dir, b
-            )
+            bin_num_error_helper_function(folderinfo, dfs, g, group_names, sc_breaks, b)
     return bin_num
 
 
-def bin_num_error_helper_function(dfs, g, group_names, sc_breaks, results_dir, b):
+def bin_num_error_helper_function(folderinfo, dfs, g, group_names, sc_breaks, b):
     """Handle this error in a separate function for readability"""
     id_col_idx = dfs[g].columns.get_loc(ID_COL)
     message = (
@@ -189,11 +186,11 @@ def bin_num_error_helper_function(dfs, g, group_names, sc_breaks, results_dir, b
         + "\nPlease re-run & make sure all bin numbers match!"
     )
     print(message)
-    write_issues_to_textfile(message, results_dir)
+    write_issues_to_textfile(message, folderinfo)
     raise ValueError(message)
 
 
-def test_PCA_and_stats_variables(df, group_name, name, results_dir, cfg):
+def check_PCA_and_stats_variables(df, group_name, name, folderinfo, cfg):
     """Tests if PCA & stats variables are present in all groups' datasets"""
     PCA_variables = cfg["PCA_variables"]
     stats_variables = cfg["stats_variables"]
@@ -215,7 +212,7 @@ def test_PCA_and_stats_variables(df, group_name, name, results_dir, cfg):
                 + "\nPlease re-run & make sure all variables are present!"
             )
             print(PCA_variable_mismatch_message)
-            write_issues_to_textfile(PCA_variable_mismatch_message, results_dir)
+            write_issues_to_textfile(PCA_variable_mismatch_message, folderinfo)
             raise ValueError(PCA_variable_mismatch_message)
     if stats_variables:
         if not all(variable in df.columns for variable in stats_variables):
@@ -235,7 +232,7 @@ def test_PCA_and_stats_variables(df, group_name, name, results_dir, cfg):
                 + "\nPlease re-run & make sure all variables are present!"
             )
             print(stats_variable_mismatch_message)
-            write_issues_to_textfile(stats_variable_mismatch_message, results_dir)
+            write_issues_to_textfile(stats_variable_mismatch_message, folderinfo)
             raise ValueError(stats_variable_mismatch_message)
 
 
@@ -247,7 +244,7 @@ def import_and_combine_dfs(
     tracking_software,
     name,
     which_leg,
-    results_dir,
+    folderinfo,
     cfg,
 ):
     """Import one run's df at a time and combine to group-level df"""
@@ -274,11 +271,11 @@ def import_and_combine_dfs(
             + ".\nSkipping!"
         )
         print(this_message)
-        write_issues_to_textfile(this_message, results_dir)
+        write_issues_to_textfile(this_message, folderinfo)
     else:
         df_copy = df.copy()
         # test: are our PCA & stats variables present in this ID's dataset?
-        test_PCA_and_stats_variables(df_copy, group_name, name, results_dir, cfg)
+        check_PCA_and_stats_variables(df_copy, group_name, name, folderinfo, cfg)
         # add some final info & append to group_df
         if tracking_software == "DLC":
             # add this run's info to df (& prepare Stepcycle column)
@@ -545,7 +542,6 @@ def idxs_list_to_list_of_SC_lists(idxs):
 
 def grand_avg_and_std(avg_dfs, folderinfo, cfg):
     """Compute the grand averages & standard deviations for all columns of df"""
-
     # unpack
     group_names = folderinfo["group_names"]
     results_dir = folderinfo["results_dir"]
@@ -595,3 +591,73 @@ def grand_avg_and_std(avg_dfs, folderinfo, cfg):
         )
         save_results_sheet(g_std_dfs[g], save_to_xls, g_std_filepath)
     return g_avg_dfs, g_std_dfs
+
+
+# %% .................  local functions #4 - load previous dataframes  .................
+def load_previous_runs_dataframes(folderinfo, cfg):
+    """If user asked for it load previous runs dataframes instead of generating them (i.e., avg_dfs, g_avg_dfs, g_std_dfs)"""
+    avg_dfs = [[]] * len(folderinfo["group_names"])
+    g_avg_dfs = [[]] * len(folderinfo["group_names"])
+    g_std_dfs = [[]] * len(folderinfo["group_names"])
+    for g, group_name in enumerate((folderinfo["group_names"])):
+        try:
+            avg_dfs[g] = pd.read_excel(
+                os.path.join(
+                    folderinfo["load_dir"],
+                    group_name + " - " + AVG_GROUP_SHEET_NAME + ".xlsx",
+                )
+            )
+            g_avg_dfs[g] = pd.read_excel(
+                os.path.join(
+                    folderinfo["load_dir"],
+                    group_name + " - " + G_AVG_GROUP_SHEET_NAME + ".xlsx",
+                )
+            )
+            g_std_dfs[g] = pd.read_excel(
+                os.path.join(
+                    folderinfo["load_dir"],
+                    group_name + " - " + G_STD_GROUP_SHEET_NAME + ".xlsx",
+                )
+            )
+        except FileNotFoundError:
+            error_msg = (
+                "\n******************\n! CRITICAL ERROR !\n******************\n"
+                + f"Unable to load the data of group '{group_name}' from \n"
+                + f"{folderinfo['load_dir']}"
+                + "\n\nTry again!"
+            )
+            print(error_msg)
+            write_issues_to_textfile(error_msg, folderinfo)
+            raise FileNotFoundError
+    # re-index avg_dfs based on unique SC Percentages
+    array_of_idxs = np.arange(len(avg_dfs[0][SC_PERCENTAGE_COL].unique()))
+    for g in range(len(avg_dfs)):
+        repeat_index_this_often = len(avg_dfs[g]) // len(array_of_idxs)
+        new_idx = np.tile(array_of_idxs, repeat_index_this_often)
+        avg_dfs[g] = avg_dfs[g].set_index(new_idx)
+    # check if PCA & stats variables are present in all dataframes
+    for g, group_name in enumerate(folderinfo["group_names"]):
+        check_PCA_and_stats_variables(
+            avg_dfs[g], group_name, "Average", folderinfo, cfg
+        )
+        check_PCA_and_stats_variables(
+            g_avg_dfs[g], group_name, "Grand Average", folderinfo, cfg
+        )
+        check_PCA_and_stats_variables(
+            g_std_dfs[g], group_name, "Grand Standard Deviation", folderinfo, cfg
+        )
+    # since import_data writes bin_num (running a sanity check before) we have to do
+    # it here too. No need to run the sanity check again since that was done previously
+    cfg["bin_num"] = len(np.unique(avg_dfs[0][SC_PERCENTAGE_COL]))
+    if cfg["bin_num"] * len(np.unique(avg_dfs[0][ID_COL])) != len(avg_dfs[0]):
+        error_msg = (
+            "\n******************\n! CRITICAL ERROR !\n******************\n"
+            + "Something is wrong with your IDs and SC Percentage columns."
+            + "\nThere seem to be duplicates. Make sure that this is not the case."
+            + "\nOtherwise, run it again without loading your previous run's results."
+        )
+        print(error_msg)
+        write_issues_to_textfile(error_msg, folderinfo)
+        raise ValueError(error_msg)
+    else:
+        return avg_dfs, g_avg_dfs, g_std_dfs, cfg
