@@ -29,6 +29,7 @@ from autogaita.gui.gui_constants import (
     AUTOGAITA_FOLDER_PATH,
     get_widget_cfg_dict,  # function!
 )
+from autogaita.group.group_constants import NORM_SHEET_NAME, AVG_GROUP_SHEET_NAME
 
 # these colors are GUI-specific - add to common widget cfg
 FG_COLOR = GROUP_FG_COLOR
@@ -41,7 +42,7 @@ WIDGET_CFG["HOVER_COLOR"] = HOVER_COLOR
 MIN_GROUP_NUM = 2
 MAX_GROUP_NUM = 6
 CONFIG_FILE_NAME = "group_gui_config.json"
-STRING_VARS = ["group_names", "group_dirs", "results_dir"]
+STRING_VARS = ["group_names", "group_dirs", "results_dir", "load_dir"]
 # note n_components can be float only for this input-check since we convert to int when
 # fitting the PCA model if it is equal to or greater than 1
 FLOAT_VARS = ["stats_threshold", "PCA_n_components"]
@@ -69,10 +70,10 @@ TK_STR_VARS = [
     "PCA_bins",
     "which_leg",
     "results_dir",
+    "load_dir",
     "color_palette",
 ]
 EXCLUDED_VARS_FROM_CFG_FILE = ["last_runs_stats_variables", "last_runs_PCA_variables"]
-NORM_SHEET_NAME = "Normalised Stepcycle"
 
 # %%...............................  MAIN PROGRAM ......................................
 
@@ -295,11 +296,15 @@ def build_mainwindow(root, group_number, root_dimensions):
         # empty label 1 for spacing
         empty_label_one = ctk.CTkLabel(mainwindow, text="")
         empty_label_one.grid(row=last_group_row, column=0, columnspan=3, sticky="nsew")
-        # results dir
-        results_dir = tk.StringVar(
-            mainwindow,
-            extract_results_dir_from_json_file(),
+
+        # NOTE! load results and load dirs as strings from cfg json before converting
+        #       to tk-vars
+        results_dir_string, load_dir_string = (
+            extract_results_and_load_dirs_from_json_files()
         )
+
+        # results dir
+        results_dir = tk.StringVar(mainwindow, results_dir_string)
         results_dir_label, results_dir_entry = gaita_widgets.label_and_entry_pair(
             mainwindow,
             "Path to save group-analysis results to",
@@ -312,10 +317,20 @@ def build_mainwindow(root, group_number, root_dimensions):
         results_dir_entry.grid(
             row=last_group_row + 2, column=0, columnspan=3, sticky="ew"
         )
+        # load dir
+        load_dir = tk.StringVar(mainwindow, load_dir_string)
+        load_dir_label, load_dir_entry = gaita_widgets.label_and_entry_pair(
+            mainwindow,
+            "Optional: path to load previous group-data from",
+            load_dir,
+            WIDGET_CFG,
+        )
+        load_dir_label.grid(row=last_group_row + 3, column=0, columnspan=3, sticky="ew")
+        load_dir_entry.grid(row=last_group_row + 4, column=0, columnspan=3, sticky="ew")
         # empty label 2 for spacing
         empty_label_two = ctk.CTkLabel(mainwindow, text="")
         empty_label_two.grid(
-            row=last_group_row + 3, column=0, columnspan=3, sticky="nsew"
+            row=last_group_row + 5, column=0, columnspan=3, sticky="nsew"
         )
         # Perm Test
         perm_checkbox = gaita_widgets.checkbox(
@@ -324,7 +339,7 @@ def build_mainwindow(root, group_number, root_dimensions):
             cfg["do_permtest"],
             WIDGET_CFG,
         )
-        perm_checkbox.grid(row=last_group_row + 4, column=0, columnspan=3, pady=10)
+        perm_checkbox.grid(row=last_group_row + 6, column=0, columnspan=3, pady=10)
         # ANOVA info
         ANOVA_checkbox = gaita_widgets.checkbox(
             mainwindow,
@@ -335,7 +350,7 @@ def build_mainwindow(root, group_number, root_dimensions):
         ANOVA_checkbox.configure(
             command=lambda: change_ANOVA_buttons_state(ANOVA_buttons),
         )
-        ANOVA_checkbox.grid(row=last_group_row + 5, column=0, columnspan=3, pady=10)
+        ANOVA_checkbox.grid(row=last_group_row + 7, column=0, columnspan=3, pady=10)
         # ANOVA design
         ANOVA_string_and_var_value = [
             ["Within-subjects (e.g. pre- & post-treatment)", "RM ANOVA"],
@@ -356,7 +371,7 @@ def build_mainwindow(root, group_number, root_dimensions):
             )
             if cfg["do_anova"].get() is True:
                 ANOVA_buttons[i].configure(state="normal")
-            ANOVA_buttons[-1].grid(row=last_group_row + 6 + i, column=0, columnspan=3)
+            ANOVA_buttons[-1].grid(row=last_group_row + 8 + i, column=0, columnspan=3)
         # initialise ANOVA buttons state by running this function once
         change_ANOVA_buttons_state(ANOVA_buttons)
 
@@ -364,7 +379,7 @@ def build_mainwindow(root, group_number, root_dimensions):
         # empty label 3 for spacing
         empty_label_three = ctk.CTkLabel(mainwindow, text="")
         empty_label_three.grid(
-            row=last_group_row + 8, column=0, columnspan=3, sticky="nsew"
+            row=last_group_row + 10, column=0, columnspan=3, sticky="nsew"
         )
 
         # advanced cfg
@@ -375,7 +390,7 @@ def build_mainwindow(root, group_number, root_dimensions):
             command=lambda: (advanced_cfgwindow(mainwindow)),
         )
         cfgwindow_button.grid(
-            row=last_group_row + 9,
+            row=last_group_row + 11,
             column=0,
             columnspan=3,
         )
@@ -391,16 +406,18 @@ def build_mainwindow(root, group_number, root_dimensions):
                     group_names,
                     group_dirs,
                     results_dir,
+                    load_dir,  # tk var
+                    cfg["which_leg"],  # tk var
                     root,
                 ),
             ),
         )
-        definefeatures_button.grid(row=last_group_row + 10, column=0, columnspan=3)
+        definefeatures_button.grid(row=last_group_row + 12, column=0, columnspan=3)
 
         # empty label four for spacing
         empty_label_four = ctk.CTkLabel(mainwindow, text="")
         empty_label_four.grid(
-            row=last_group_row + 11, column=1, columnspan=3, sticky="ns"
+            row=last_group_row + 13, column=1, columnspan=3, sticky="ns"
         )
 
         # exit button
@@ -412,7 +429,7 @@ def build_mainwindow(root, group_number, root_dimensions):
                 mainwindow.after(5000, mainwindow.destroy),
             ),
         )
-        exit_button.grid(row=last_group_row + 12, column=0, columnspan=3)
+        exit_button.grid(row=last_group_row + 14, column=0, columnspan=3)
 
         # maximise widgets to fit fullscreen
         maximise_widgets(mainwindow)
@@ -578,7 +595,9 @@ def advanced_cfgwindow(mainwindow):
 # %%..............  LOCAL FUNCTION(S) #3 - BUILD ADD FEATURES WINDOW  ..................
 
 
-def definefeatures_window(mainwindow, group_names, group_dirs, results_dir, root):
+def definefeatures_window(
+    mainwindow, group_names, group_dirs, results_dir, load_dir, which_leg, root
+):
     """Build define features window"""
 
     # nested function (called by run-button): extract boolean checkbox vars and store
@@ -594,47 +613,62 @@ def definefeatures_window(mainwindow, group_names, group_dirs, results_dir, root
             ]
 
     # ...................  EXTRACT FEATURES FROM AN AVERAGE SC XLS  ....................
+    # => Only needed if not loading a previous run (note there is a check for features
+    #    being present in all dfs in load_previous_runs_dataframes in group_main)
     # => First read the xls as df, extract columns that are meaningful after
     #    averaging, or throw errors if we don't manage to do so
     #    -- (note we extract from average xls since that automatically informs about
     #        export_average_x/y vars!)
-    df = None
-    test_directories = []  # first see if all group dirs are valid paths
-    for directory in group_dirs:
-        test_directories.append(directory.get())
-    for directory in test_directories:
-        if not os.path.exists(directory):
-            error_msg = "No directory found at: " + directory
+    if len(load_dir.get()) > 0:
+        group_one_string = group_names[0].get()
+        load_dir_string = load_dir.get()
+        df = pd.read_excel(
+            os.path.join(
+                load_dir_string, f"{group_one_string} - {AVG_GROUP_SHEET_NAME}.xlsx"
+            )
+        )
+    else:
+        df = None
+        test_directories = []  # first see if all group dirs are valid paths
+        for directory in group_dirs:
+            test_directories.append(directory.get())
+        for directory in test_directories:
+            if not os.path.exists(directory):
+                error_msg = "No directory found at: " + directory
+                tk.messagebox.showerror(title="Folder not found!", message=error_msg)
+                return
+        if not results_dir.get():
+            error_msg = "You did not specify a directory to save results to!"
             tk.messagebox.showerror(title="Folder not found!", message=error_msg)
             return
-    if not results_dir.get():
-        error_msg = "You did not specify a directory to save results to!"
-        tk.messagebox.showerror(title="Folder not found!", message=error_msg)
-        return
-    if not os.path.exists(results_dir.get()):  # for results dir, create if not there
-        os.makedirs(results_dir.get())
-    some_groups_dir = group_dirs[0].get()
-    all_ID_dirs = [
-        f
-        for f in os.listdir(some_groups_dir)
-        if os.path.isdir(os.path.join(some_groups_dir, f))
-    ]
-    for ID_dir in all_ID_dirs:
-        some_IDs_dir = os.path.join(some_groups_dir, ID_dir)
-        IDs_files = os.listdir(some_IDs_dir)
-        # next operator means we loop lazy - stop once we find it & return None if av
-        # sheet not in dir
-        av_sheet_path = next(
-            (file for file in IDs_files if NORM_SHEET_NAME in file), None
-        )
-        if av_sheet_path:  # won't be true if no AVXLS found
-            full_path = os.path.join(some_IDs_dir, av_sheet_path)
-            if av_sheet_path.endswith(".xlsx"):
-                df = pd.read_excel(full_path)
-                break
-            elif av_sheet_path.endswith(".csv"):
-                df = pd.read_csv(full_path)
-                break
+        if not os.path.exists(results_dir.get()):
+            os.makedirs(results_dir.get())
+        some_groups_dir = group_dirs[0].get()
+        all_ID_dirs = [
+            f
+            for f in os.listdir(some_groups_dir)
+            if os.path.isdir(os.path.join(some_groups_dir, f))
+        ]
+        for ID_dir in all_ID_dirs:
+            some_IDs_dir = os.path.join(some_groups_dir, ID_dir)
+            IDs_files = os.listdir(some_IDs_dir)
+            # next operator means we loop lazy - stop once we find it & return None if av
+            # sheet not in dir
+            av_sheet_path = next(
+                (file for file in IDs_files if NORM_SHEET_NAME in file), None
+            )
+            if av_sheet_path:  # won't be true if no AVXLS found
+                full_path = os.path.join(some_IDs_dir, av_sheet_path)
+                if av_sheet_path.endswith(".xlsx"):
+                    try:
+                        # universal 3D (that has which_leg sheets) always exports xlsx
+                        df = pd.read_excel(full_path, sheet_name=which_leg.get())
+                    except:
+                        df = pd.read_excel(full_path)
+                    break
+                elif av_sheet_path.endswith(".csv"):
+                    df = pd.read_csv(full_path)
+                    break
     # select columns we want to provide as feature options using regular expressions
     # => since it's on av sheet, x & Y will only be included if export_average_x/Y was
     #    True @ first-level
@@ -680,7 +714,7 @@ def definefeatures_window(mainwindow, group_names, group_dirs, results_dir, root
     #    (i.e., True) or not. we will store all true checkboxes for both PCA and stats
     #    later (but it's handy that the key names overlap)
     checkbox_vars = {key: {} for key in LIST_VARS}
-    for f_idx, frame in enumerate([stats_frame, PCA_frame]):
+    for frame in [stats_frame, PCA_frame]:
         if frame == stats_frame:  # make sure to put stuff into the correct dict
             key = "stats_variables"
         elif frame == PCA_frame:
@@ -723,6 +757,7 @@ def definefeatures_window(mainwindow, group_names, group_dirs, results_dir, root
                 group_names,
                 group_dirs,
                 results_dir,
+                load_dir,
                 root,
                 mainwindow,
                 featureswindow,
@@ -740,7 +775,7 @@ def definefeatures_window(mainwindow, group_names, group_dirs, results_dir, root
 
 # %%..................  LOCAL FUNCTION(S) #4 - BUILD DONE WINDOW  ......................
 def build_donewindow(
-    group_names, group_dirs, results_dir, root, mainwindow, featureswindow
+    group_names, group_dirs, results_dir, load_dir, root, mainwindow, featureswindow
 ):
     """Build done window"""
     # create done window & make it pretty and nice
@@ -799,11 +834,17 @@ def build_donewindow(
     # ..................................................................................
     # ........................  IMPORTANT - prepare folderinfo .........................
     # ..................................................................................
-    folderinfo = {"group_names": [], "group_dirs": [], "results_dir": ""}
+    folderinfo = {
+        "group_names": [],
+        "group_dirs": [],
+        "results_dir": "",
+        "load_dir": "",
+    }
     for g in range(len(group_names)):
         folderinfo["group_names"].append(group_names[g].get())
         folderinfo["group_dirs"].append(group_dirs[g].get())
     folderinfo["results_dir"] = results_dir.get()
+    folderinfo["load_dir"] = load_dir.get()
 
     # run button
     done_button = ctk.CTkButton(
@@ -876,7 +917,7 @@ def check_folderinfo_and_cfg(folderinfo, cfg):
         for key in inner_dict.keys():
             # check string vars: group dirs & names and results dir
             if key in STRING_VARS:
-                if key == "group_dirs":
+                if key == "group_dirs" and len(folderinfo["load_dir"]) > 0:
                     for g_idx, group_dir in enumerate(inner_dict[key]):
                         if not os.path.exists(group_dir):
                             this_msg = (
@@ -931,8 +972,8 @@ def extract_this_runs_folderinfo_and_cfg(folderinfo, cfg):
     # using string concatenation). If not just add a forward slash. In the beginning
     # of autogaita.group, we will convert os.sep to forward slashes if they should be
     # backward slashes (windows works with both)
-    # => Note this was changed and works with os.path.join() now...
-    # => NU: have another look @ this matter in GUI functions
+    # => The part that does this in autogaita.group was updated and uses os.path.join
+    # => Thought about changing strings to Paths here but will leave it for now it works
     for key in folderinfo.keys():
         if key == "group_names":
             this_runs_folderinfo[key] = folderinfo[key]
@@ -944,8 +985,9 @@ def extract_this_runs_folderinfo_and_cfg(folderinfo, cfg):
                         this_runs_folderinfo[key][i] = folderinfo[key][i] + "/"
                     else:
                         this_runs_folderinfo[key][i] = folderinfo[key][i]
-            else:  # results_dir
-                if not folderinfo[key].endswith(os.sep):
+            # results_dir and load_dir (check load_dir only if not empty)
+            elif key in ["results_dir", "load_dir"]:
+                if len(folderinfo[key]) > 0 and not folderinfo[key].endswith(os.sep):
                     this_runs_folderinfo[key] = folderinfo[key] + "/"
                 else:
                     this_runs_folderinfo[key] = folderinfo[key]
@@ -1044,7 +1086,10 @@ def fix_window_after_its_creation(window):
 def update_config_file(folderinfo, cfg):
     """updates the group_gui_config file with this folderinfo and cfg parameters"""
     # transform tkVars into normal strings and bools
-    output_dicts = [{"group_names": [], "group_dirs": [], "results_dir": ""}, {}]
+    output_dicts = [
+        {"group_names": [], "group_dirs": [], "results_dir": "", "load_dir": ""},
+        {},
+    ]
 
     for i in range(len(output_dicts)):
         if i == 0:  # as the list index 0 refers to  folderinfo
@@ -1139,7 +1184,7 @@ def extract_group_names_and_dirs_from_json_file():
     return group_names, group_dirs
 
 
-def extract_results_dir_from_json_file():
+def extract_results_and_load_dirs_from_json_files():
     """loads the results dir from the config file"""
     # load the configuration file
     with open(
@@ -1149,8 +1194,9 @@ def extract_results_dir_from_json_file():
         last_runs_folderinfo = json.load(config_json_file)[0]
 
     results_dir = last_runs_folderinfo["results_dir"]
+    load_dir = last_runs_folderinfo["load_dir"]
 
-    return results_dir
+    return results_dir, load_dir
 
 
 # %% what happens if we hit run
